@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.5.4);
+  our $VERSION = qv(8.5.5);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -205,10 +205,6 @@ sub filter {
   our %rcache;
   my $pkg = caller;
 
-  # handle bare typed lexical declarations
-  s/^\s*my\s+(\w[\w:]*)\s+(\$\w+)(.)/$3 eq ";" ? qq(BEGIN{local \$@; eval "require $1"} my $1 $2; {no strict qw!vars subs!; no warnings 'once'; $2 = $1})
-    : qq(BEGIN {local \$@; eval "require $1"} my $1 $2$3)/gmse if $status > 0;
-
   # NEW in v8.x.y: handle signatures
   no warnings 'uninitialized';
   s(^
@@ -248,10 +244,15 @@ sub filter {
       $suffix = "" unless $entry;
     }
 
-    warn "$prefix { $suffix";
+#    warn "$prefix { $suffix";
     "$prefix { no warnings qw/experimental shadow/; $suffix";
   )gmsex if $status > 0;
 
+  # handle bare typed lexical declarations
+  s/(^|;)\s*my\s+(\w[\w:]*)\s+(\$\w+)(.)/$4 eq ";"
+    ? qq($1BEGIN{local \$@; eval "require $2"} my $2 $3$4 {no strict qw!vars subs!; no warnings 'once'; $3 = $2})
+    : qq($1BEGIN{local \$@; eval "require $2"} my $2 $3$4)/gmse if $status > 0;
+
   return $status;
 }
 
